import React, { useState, useEffect } from 'react';
import { FaShoppingCart, FaUsers, FaMoneyBillWave, FaExclamationTriangle } from 'react-icons/fa';
import { Bar, Line } from 'react-chartjs-2';
import {
  Chart as ChartJS,
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  BarElement,
  Title,
  Tooltip,
  Legend,
  ChartOptions
} from 'chart.js';
import { get } from '@/lib/api-client';
import Card from '@/components/common/Card';
import Button from '@/components/common/Button';
import ErrorBoundary from '@/components/ErrorBoundary';
import styles from '@/styles/admin/Dashboard.module.scss';

// Register Chart.js components
ChartJS.register(
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  BarElement,
  Title,
  Tooltip,
  Legend
);

interface DashboardSummary {
  totalSales: number;
  totalOrders: number;
  totalCustomers: number;
  pendingOrders: number;
}

interface SalesData {
  labels: string[];
  values: number[];
}

interface TopProduct {
  _id: string;
  name: string;
  sales: number;
}

const Dashboard: React.FC = () => {
  const [summary, setSummary] = useState<DashboardSummary>({
    totalSales: 0,
    totalOrders: 0,
    totalCustomers: 0,
    pendingOrders: 0,
  });
  const [salesData, setSalesData] = useState<SalesData>({
    labels: [],
    values: [],
  });
  const [topProducts, setTopProducts] = useState<TopProduct[]>([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);
  const [timeFrame, setTimeFrame] = useState<'week' | 'month' | 'year'>('week');

  useEffect(() => {
    fetchDashboardData();
  }, [timeFrame]);

  async function fetchDashboardData() {
    try {
      setLoading(true);
      setError(null);

      const [summaryResponse, salesResponse, productsResponse] = await Promise.all([
        get<DashboardSummary>('/api/admin/dashboard/summary'),
        get<SalesData>(`/api/admin/dashboard/sales?timeFrame=${timeFrame}`),
        get<TopProduct[]>('/api/admin/dashboard/top-products'),
      ]);

      if (summaryResponse.success && summaryResponse.data) {
        setSummary(summaryResponse.data);
      }

      if (salesResponse.success && salesResponse.data) {
        setSalesData(salesResponse.data);
      }

      if (productsResponse.success && productsResponse.data) {
        setTopProducts(productsResponse.data);
      }
    } catch (err) {
      console.error('Error fetching dashboard data:', err);
      setError('Có lỗi khi tải dữ liệu dashboard');
    } finally {
      setLoading(false);
    }
  }

  // Chart options
  const salesChartOptions: ChartOptions<'line'> = {
    responsive: true,
    plugins: {
      legend: {
        position: 'top' as const,
      },
      title: {
        display: true,
        text: 'Doanh thu theo thời gian',
      },
    },
    scales: {
      y: {
        beginAtZero: true,
        ticks: {
          callback: function(value) {
            return value.toLocaleString('vi-VN') + 'đ';
          }
        }
      }
    },
  };

  const productChartOptions: ChartOptions<'bar'> = {
    responsive: true,
    plugins: {
      legend: {
        display: false,
      },
      title: {
        display: true,
        text: 'Sản phẩm bán chạy',
      },
    },
    scales: {
      y: {
        beginAtZero: true,
      }
    },
  };

  // Chart data
  const salesChartData = {
    labels: salesData.labels,
    datasets: [
      {
        label: 'Doanh thu',
        data: salesData.values,
        fill: false,
        backgroundColor: 'rgba(75, 192, 192, 0.2)',
        borderColor: 'rgba(75, 192, 192, 1)',
        tension: 0.1
      }
    ],
  };

  const productChartData = {
    labels: topProducts.map(p => p.name),
    datasets: [
      {
        label: 'Số lượng bán',
        data: topProducts.map(p => p.sales),
        backgroundColor: 'rgba(54, 162, 235, 0.5)',
        borderColor: 'rgb(54, 162, 235)',
        borderWidth: 1
      }
    ],
  };

  return (
    <div className={styles.dashboardContainer}>
      {error && (
        <div className={styles.errorMessage}>
          <FaExclamationTriangle />
          <p>{error}</p>
          <Button onClick={fetchDashboardData} variant="primary" size="sm">
            Thử lại
          </Button>
        </div>
      )}

      {/* Quick stats */}
      <div className={styles.statsGrid}>
        <Card className={styles.statCard}>
          <div className={styles.statIcon}>
            <FaMoneyBillWave />
          </div>
          <div className={styles.statContent}>
            <h3>Tổng doanh thu</h3>
            <div className={styles.statValue}>
              {summary.totalSales.toLocaleString('vi-VN')}đ
            </div>
          </div>
        </Card>

        <Card className={styles.statCard}>
          <div className={styles.statIcon}>
            <FaShoppingCart />
          </div>
          <div className={styles.statContent}>
            <h3>Đơn hàng</h3>
            <div className={styles.statValue}>{summary.totalOrders}</div>
          </div>
        </Card>

        <Card className={styles.statCard}>
          <div className={styles.statIcon}>
            <FaUsers />
          </div>
          <div className={styles.statContent}>
            <h3>Khách hàng</h3>
            <div className={styles.statValue}>{summary.totalCustomers}</div>
          </div>
        </Card>

        <Card className={styles.statCard}>
          <div className={`${styles.statIcon} ${styles.pendingIcon}`}>
            <FaExclamationTriangle />
          </div>
          <div className={styles.statContent}>
            <h3>Đơn chờ xử lý</h3>
            <div className={styles.statValue}>{summary.pendingOrders}</div>
          </div>
        </Card>
      </div>

      {/* Sales Chart */}
      <Card className={styles.chartCard}>
        <div className={styles.chartHeader}>
          <h2>Thống kê doanh thu</h2>
          <div className={styles.timeFrameButtons}>
            <Button 
              variant={timeFrame === 'week' ? 'primary' : 'outline'} 
              size="sm" 
              onClick={() => setTimeFrame('week')}
            >
              7 Ngày
            </Button>
            <Button 
              variant={timeFrame === 'month' ? 'primary' : 'outline'} 
              size="sm" 
              onClick={() => setTimeFrame('month')}
            >
              30 Ngày
            </Button>
            <Button 
              variant={timeFrame === 'year' ? 'primary' : 'outline'} 
              size="sm" 
              onClick={() => setTimeFrame('year')}
            >
              Năm
            </Button>
          </div>
        </div>

        <ErrorBoundary>
          <div className={styles.chartContainer}>
            {loading ? (
              <div className={styles.loadingPlaceholder}>
                Đang tải dữ liệu...
              </div>
            ) : (
              <Line options={salesChartOptions} data={salesChartData} />
            )}
          </div>
        </ErrorBoundary>
      </Card>

      {/* Products Chart */}
      <div className={styles.chartsRow}>
        <Card className={styles.chartCard}>
          <h2>Top sản phẩm bán chạy</h2>
          <ErrorBoundary>
            <div className={styles.chartContainer}>
              {loading ? (
                <div className={styles.loadingPlaceholder}>
                  Đang tải dữ liệu...
                </div>
              ) : (
                <Bar options={productChartOptions} data={productChartData} />
              )}
            </div>
          </ErrorBoundary>
        </Card>

        <Card className={styles.recentOrdersCard}>
          <h2>Đơn hàng gần đây</h2>
          <div className={styles.recentOrdersList}>
            {/* Recent orders would go here */}
            <Button href="/admin/orders" variant="text" className={styles.viewAllLink}>
              Xem tất cả đơn hàng
            </Button>
          </div>
        </Card>
      </div>
    </div>
  );
};

export default Dashboard;